==> fotoalbum-0.33.tar.bz2: fotoalbum-0.33/src/gui_fltk/picbox.h <==
/*
 * Copyright (C) 2005,2008  Jens Wilhelm Wulf, j dot w dot wulf at gmx dot net
 * Licensed under the GNU General Public License version 2.
 */

#ifndef PICBOX_H
# define PICBOX_H

# include <string>
# include <FL/Fl_Box.H>
# include <FL/Fl_RGB_Image.H>
# include "../base/treepicbase.h"
# include "textbox.h"
# include "cache.h"
# include "optionen.h"

class PicBox;

class LoadAndScaleData
{
public:
  int nQualOverSpeed;
  CachedPic* pCachedPic;
  std::string errstring;
  TreePicBase* newpic;
  float flAspectRatio;
  Fl_RGB_Image* res;
  Fl_RGB_Image* res_fast;
  bool fThread;
  bool fActive;
  int  nRetCode;
  PicBox* pPicBox;
  
  LoadAndScaleData()
  {
    fActive    = false;
    fThread    = false;
    res        = 0;
    res_fast   = 0;
    pCachedPic = 0;
    pPicBox    = 0;
    newpic     = 0;
    nQualOverSpeed = 1;
  };
};


/**
 * picture display
 */
class PicBox : public Fl_Box
{
public:
  PicBox(int,int,int,int, const char * = 0);
  virtual ~PicBox();
  int handle(int);
  
  enum eCallback { PICTURE_NEXT, PICTURE_PREV, GROUP, CONTEXT, PROPERTIES, TOGGLE_MARK, ADD_KEYWORDS };
  virtual void resize(int x, int y, int w, int h);   
  
  int setPic(TreePicBase* newpic, 
             std::string  basepath,
             T_optionen*  opts);
  inline TreePicBase* getPic() { return(myPic); };
  
  void draw();
  
  /**
   * Wird derzeit nur von UserInterface aufgerufen, wenn sich die Markierung geändert hat.
   */
  void redrawTextBox();
  
  void boxcallback(Fl_Callback* fnptr, void* dtptr);
  
  int nMX;
  int nMY;
  
  /**
   * This is because FLTK 1.1 in debian sarge doesn't implement Fl_Widget::copy_label()
   */
  void setLabel(std::string somestring);

  void SetFastImg(Fl_RGB_Image* pImg);
  
  static PicCache* pPicCache;

private:

  void toggleVerbosity();
  
  TreePicBase* myPic;
  Fl_RGB_Image* myRGBImg;
  Fl_RGB_Image* pFastImg;
  
  /**
   * 
   */
  void setDescr(std::string newdescr);
  
  /**
   * displays additional information
   */
  TextBox* textbox;
  
  /**
   * verbose additional info?
   */
  int nVerbose;
  
  /**
   *
   */
  std::string mylabel;
    
  LoadAndScaleData lasd_thread;
};
#endif

==> fotoalbum-0.201.tar.bz2: fotoalbum-0.201/src/gui_fltk/picbox.h <==
/*
 * Copyright (C) 2005,2008, 2012  Jens Wilhelm Wulf, j dot w dot wulf at gmx dot net
 * Licensed under the GNU General Public License version 2.
 */

#ifndef PICBOX_H
# define PICBOX_H

# include <string>
# include <inttypes.h>
# include <FL/Fl_Box.H>
# include <FL/Fl_RGB_Image.H>
# include "textbox.h"
# include "cache.h"
# include "optionen.h"

class PicBox;
class ItPic;
class ItPicInGroup;
class TreeView;
class UserInterface;

class LoadAndScaleData
{
public:
  int nQualOverSpeed;
  CachedPic* pCachedPic;
  std::string errstring;
  ItPic* newpic;
  float flAspectRatio;
  Fl_RGB_Image* res;
  Fl_RGB_Image* res_fast;
  bool fThread;
  bool fActive;
  intptr_t nRetCode;
  PicBox* pPicBox;
  
  LoadAndScaleData()
  {
    fActive    = false;
    fThread    = false;
    res        = 0;
    res_fast   = 0;
    pCachedPic = 0;
    pPicBox    = 0;
    newpic     = 0;
    nQualOverSpeed = 1;
  };
};


/**
 * picture display
 */
class PicBox : public Fl_Box
{
public:
  PicBox(int,int,int,int, const char * = 0);
  virtual ~PicBox();
  int handle(int);
  
  enum eCallback { PICTURE_NEXT=1, PICTURE_PREV=2, GROUP=3, CONTEXT=4, PROPERTIES=5, TOGGLE_MARK=6, ADD_KEYWORDS=7, RATE=100 };
  virtual void resize(int x, int y, int w, int h);   
  
  int setPic(ItPicInGroup*  newpic,
             TreeView*      pTreeView,
             T_optionen*    opts,
             UserInterface* pGUI);
  ItPicInGroup* getPic() { return(myPic); };
  
  void draw();
  
  /**
   * Wird derzeit nur von UserInterface aufgerufen, wenn sich die Markierung geändert hat.
   */
  void redrawTextBox();
  void UpdateTextBox();
  
  void boxcallback(Fl_Callback* fnptr, void* dtptr);

  /**
   * mouse coordinate when activating context menu
   */
  int nMX;
  int nMY;
  
  /**
   * This is because FLTK 1.1 in debian sarge doesn't implement Fl_Widget::copy_label()
   */
  void setLabel(std::string somestring);

  void SetFastImg(Fl_RGB_Image* pImg);
  
  static PicCache* pPicCache;
  
  ItPicInGroup* PicNext();
  ItPicInGroup* PicPrev();
  
private:

  void toggleVerbosity();
  
  ItPicInGroup* myPic;
  Fl_RGB_Image* myRGBImg;
  Fl_RGB_Image* pFastImg;
  TreeView* pTreeView;
  UserInterface* pGUI;
  
  /**
   * 
   */
  void setDescr(std::string newdescr);
  
  /**
   * displays additional information
   */
  TextBox* textbox;
  
  /**
   * verbose additional info?
   */
  int nVerbose;
  
  /**
   *
   */
  std::string mylabel;
    
  LoadAndScaleData lasd_thread;
};
#endif
